import logging

import pyudev

def is_display_connected(card: str, connector: str) -> bool:
    logger = logging.getLogger("udev")
    status_file = f"/sys/class/drm/{card}-{connector}/status"
    logger.debug("Reading file %s", status_file)
    with open(status_file, "r") as f:
        result = f.read().strip()
        logger.debug("Result: '%s'", result)
        return result == "connected"

def block_until_display_connected(card: str, connector: str):
    ctx = pyudev.Context()
    monitor = pyudev.Monitor.from_netlink(ctx)
    monitor.filter_by("drm")
    for device in iter(monitor.poll, None):
        if not "DEVNAME" in device:
            continue
        
        if device.get("DEVNAME") != f"/dev/dri/{card}":
            continue
        
        if not is_display_connected(card, connector):
            continue
        break